@@ -1,18 +1,18 @@
 package MIDI::RtController::Filter::Drums;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: RtController drum filters
+# ABSTRACT: Generic RtController drum filter
 
 use v5.36;
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0304';
 
 use strictures 2;
 use List::SomeUtils qw(first_index);
 use MIDI::Drummer::Tiny ();
 use MIDI::RtMidi::ScorePlayer ();
 use Moo;
-use Types::Standard qw(ArrayRef CodeRef Num Maybe);
+use Types::Standard qw(ArrayRef CodeRef HashRef Num Maybe);
 use namespace::clean;
 
 
@@ -66,7 +66,14 @@ sub _build_phrase {
 }
 
 
-sub _drum_parts ($self, $note) {
+has common => (
+    is  => 'rw',
+    isa => HashRef,
+    default => sub { {} },
+);
+
+
+sub _drum_part ($self, $note) {
     my $part;
     if (defined $self->trigger && $note == $self->trigger) {
         $part = $self->phrase;
@@ -81,15 +88,17 @@ sub _drum_parts ($self, $note) {
 }
 sub drums ($self, $device, $dt, $event) {
     my ($ev, $chan, $note, $val) = $event->@*;
-    my $part = $self->_drum_parts($note);
+    my $part = $self->_drum_part($note);
     my $d = MIDI::Drummer::Tiny->new(
         bpm  => $self->bpm,
         bars => $self->bars,
     );
+    my $common = $self->common;
+    $common = { %$common, drummer => $d };
     MIDI::RtMidi::ScorePlayer->new(
       device   => $self->rtc->midi_out,
       score    => $d->score,
-      common   => { drummer => $d },
+      common   => $common,
       parts    => [ $part ],
       sleep    => 0,
       infinite => 0,
@@ -107,16 +116,16 @@ __END__
 
 =head1 NAME
 
-MIDI::RtController::Filter::Drums - RtController drum filters
+MIDI::RtController::Filter::Drums - Generic RtController drum filter
 
 =head1 VERSION
 
-version 0.0301
+version 0.0304
 
 =head1 SYNOPSIS
 
   use curry;
-  use Future::IO::Impl::IOAsync;
+  use Future::IO::Impl::IOAsync; # because ScorePlayer is async
   use MIDI::RtController ();
   use MIDI::RtController::Filter::Drums ();
 
@@ -129,8 +138,9 @@ version 0.0301
   my $filter = MIDI::RtController::Filter::Drums->new(rtc => $controller);
 
   $filter->phrase(\&my_phrase);
-  $filter->trigger(99); # trigger the phrase
+  $filter->trigger(99); # trigger the phrase with note 99
   $filter->bars(8);
+  $filter->common({ foo => 42 });
 
   $controller->add_filter('drums', note_on => $filter->curry::drums);
 
@@ -138,14 +148,18 @@ version 0.0301
 
   sub my_phrase {
     my (%args) = @_;
-    $args{drummer}->metronome7;
+    if ($args{foo} == 42) {
+      $args{drummer}->metronome4;
+    }
+    else {
+      $args{drummer}->metronome5;
+    }
   }
 
 =head1 DESCRIPTION
 
-C<MIDI::RtController::Filter::Drums> is the L<MIDI::RtController>
-filter for the drums. It is meant to be an example of how to make a
-drum filter and uses the 4/4 metronome for this.
+C<MIDI::RtController::Filter::Drums> is a generic
+L<MIDI::RtController> drum filter.
 
 =head1 ATTRIBUTES
 
@@ -205,6 +219,20 @@ The subroutine given to this attribute takes a collection of named
 parameters to do its thing. Primarily, this is a
 L<MIDI::Drummer::Tiny> instance named "drummer."
 
+=head2 common
+
+  $common = $filter->common;
+  $filter->common($common);
+
+These are custom arguments given to the phrase.
+
+A L<MIDI::Tiny::Drummer> instance, named "drummer" is added to this
+list when executing the B<phrase>.
+
+Default: C<{}> (no arguments)
+
+Default: C<120>
+
 =head1 METHODS
 
 All filter methods must accept the object, a MIDI device name, a
